# Code Review

All code submitted into the plaso project goes through code review. We use the GitHub codereview process, which while not perfect, is good enough for our purposes.

One helpful hint is while you have a code in code review monitor the development mailing list for large changes or new dependencies that may potentially affect your code. Such changes may include code re-factors that change plugin interface while you have a plugin in review. These should be rare but they do happen every now and then.

## Process
Plaso follows the [Log2timeline project code review process](https://github.com/log2timeline/l2tdocs/blob/master/process/Code%20review%20process.md)